.. gym-softrobot master file, created by
   sphinx-quickstart on Wed Mar 16 17:11:27 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

*******************************
Gym-Softrobot Environment Suite
*******************************

.. badges

.. toctree::
   :maxdepth: 2
   :caption: Environment

   envs/design
   envs/octopus
   envs/soft_arm
   envs/misc

.. toctree::
   :maxdepth: 2
   :caption: Other

   envs/wrappers


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
